@@ -14,5 +14,5 @@ class ID3:
     def classify(self):
         for xtest in self.data_test:
             print("The test instance:",xtest)
-            print("The label for test instance:",end="   ")   
-            classify(self.node,xtest,self.features_test)  
+            print("The label for test instance:")   
+            classify(self.node,xtest,self.features_test)
\ No newline at end of file
